Mise à jour en cours...
Mise à jour reussi...
Echec mise à jour...
sondes

7 | T° extérieure | 17.5 | °
11 | T° départ condenseur | 30.2 | °
12 | T° retour condenseur | 28.5 | °
1 | Basse pression | 10.0 | bar
2 | Haute pression | 10.4 | bar
1 | T° évaporation | 11.4 | °
2 | T° condensation | 11.9 | °
8 | T° évaporateur | 22.3 | °
3 | Débit chauffage | 0.0 | l/m
9 | T° entrée évaporateur | 15.3 | °
10 | T° sortie évaporateur | 14.6 | °
13 | T° ballon tampon | 32.4 | °
13 | T° ballon technique | 32.5 | °
19 | T° ambiance zone 1 | 19.2 | °
15 | Correction Zone 1 | 50.6 | digit